import 'package:flutter/material.dart';
import 'api_service.dart';
import 'structs.dart';

class EmailListScreen extends StatelessWidget {
  final List<GetThreadResponse> emails;
  final Future<String> Function(List<String>) getEmailContent;

  EmailListScreen({required this.emails, required this.getEmailContent});

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: ListView.separated(
        itemCount: emails.length,
        itemBuilder: (context, index) {
          final email = emails[index];
          return ListTile(
            title: Text(email.from_name,
                style: TextStyle(fontWeight: FontWeight.bold)),
            subtitle: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [Text(email.subject)],
            ),
            trailing: Text(email.date.toString()),
            onTap: () async {
              String emailContent = await getEmailContent(email.messages);
              Navigator.push(
                context,
                MaterialPageRoute(
                  builder: (context) => EmailView(
                    emailContent: emailContent,
                    from: email.from_address,
                    name: email.from_name,
                    to: email.to.toString(),
                    subject: email.subject,
                    date: email.date.toString(),
                    id: email.id.toString(),
                  ),
                ),
              );
            },
          );
        },
        separatorBuilder: (context, index) => Divider(),
      ),
    );
  }
}

class EmailPage extends StatefulWidget {
  EmailPage({Key? key}) : super(key: key);
  String selectedFolder = "INBOX";
  
  @override
  EmailPageState createState() => EmailPageState();
}

class EmailPageState extends State<EmailPage> {
  final ApiService apiService = ApiService();
  List<GetThreadResponse> emails = [];

  void updateSelectedFolder(String folder) {
    setState(() {
      widget.selectedFolder = folder;
    });
    print(folder);
    _fetchEmails();
  }

  void _fetchEmails() async {
    // print(selectedFolder)
    try {
      List<GetThreadResponse> fetchedEmails =
          await apiService.fetchEmailsFromFolder(widget.selectedFolder, 0);
      setState(() {
        emails = fetchedEmails; // Update the list of emails
      });
    } catch (e) {
      print('Error fetching emails: $e');
    }
  }

  @override
  Widget build(BuildContext context) {
    _fetchEmails();
    return Scaffold(
      body: EmailListScreen(
        emails: emails,
        getEmailContent: apiService.fetchEmailContent,
      ),
    );
  }
}
